test: cleanups
diff --git a/test/test_util.py b/test/test_util.py
index cd0e0fb..664340f 100644
--- a/test/test_util.py
+++ b/test/test_util.py
@@ -27,7 +27,6 @@
         self.assertEqual(list(serial.iterbytes(b'\x01\x02\x03')), [b'\x01', b'\x02', b'\x03'])
 
 
-
 if __name__ == '__main__':
     import sys
     sys.stdout.write(__doc__)
diff --git a/test/test_threaded.py b/test/test_threaded.py
index 333a5c0..40f45ad 100644
--- a/test/test_threaded.py
+++ b/test/test_threaded.py
@@ -18,8 +18,8 @@
 # on which port should the tests be performed:
 PORT = 'loop://'
 
-class Test_asyncio(unittest.TestCase):
-    """Test asyncio related functionality"""
+class Test_threaded(unittest.TestCase):
+    """Test serial.threaded related functionality"""
 
     def test_line_reader(self):
         """simple test of line reader class"""